==> nextcloud-app-spreed-1:15.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_AR.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "Guest" : "Invitado",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Se presentó un error. Favor de contactar a su adminsitrador. ",
    "Open settings" : "Abrir opciones",
    "Messages" : "Mensajes",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : "Ususarios",
    "Name" : "Nombre",
    "General settings" : "Configuraciones generales",
    "Off" : "Apagado",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "OK" : "OK",
    "Copy link" : "Copiar enlace",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "Dismiss" : "Despedir",
    "Show your screen" : "Mostrar su pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Grid view" : "Vista de cuadrícula",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Back" : "Atrás",
    "You" : "Usted",
    "Favorite" : "Favorito",
    "Restricted" : "Restringido",
    "Description" : "Descripción",
    "Notifications" : "Notificaciones",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Eliminar conversación",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingrese una contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Eliminar",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Inicio de sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger con contraseña",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de conversación",
    "Reply" : "Responder",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Send message" : "Enviar mensaje",
    "New file" : "Nuevo archivo",
    "Settings" : "Ajustes",
    "Searching …" : "Buscando ...",
    "No results" : "Sin resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Search" : "Buscar",
    "Rename conversation" : "Renombrar conversación",
    "Send" : "Enviar",
    "Start a conversation" : "Iniciar una conversación",
    "Media" : "Media",
    "Files" : "Archivos",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Do not disturb" : "No molestar",
    "Away" : "Lejos",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
    "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "Saved" : "Guardado",
    "Camera" : "Cámara"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-spreed-1:17.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_AR.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "Guest" : "Invitado",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Dismiss notification" : "Eliminar notificación",
    "Open settings" : "Abrir opciones",
    "Messages" : "Mensajes",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "Beta" : "Beta",
    "Name" : "Nombre",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : "Ususarios",
    "General settings" : "Configuraciones generales",
    "Off" : "Apagado",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "OK" : "OK",
    "Back" : "Atrás",
    "Confirm" : "Confirmar",
    "Reset" : "Restablecer",
    "Cancel" : "Cancelar",
    "Copy link" : "Copiar enlace",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "You" : "Usted",
    "Collapse" : "Colapsar",
    "Favorite" : "Favorito",
    "Description" : "Descripción",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Permissions" : "Permisos",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Eliminar conversación",
    "Submit" : "Enviar",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Eliminar",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Inicio de sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Notifications" : "Notificaciones",
    "Remove from favorites" : "Eliminado de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger con contraseña",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de conversación",
    "Devices" : "Dispositivos",
    "Done" : "Terminado",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "Dismiss" : "Despedir",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Send message" : "Enviar mensaje",
    "Group" : "Grupo",
    "New file" : "Nuevo archivo",
    "Settings" : "Ajustes",
    "Send" : "Enviar",
    "Searching …" : "Buscando ...",
    "No results" : "Sin resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Search" : "Buscar",
    "Open sidebar" : "Abrir barra lateral",
    "Show your screen" : "Mostrar su pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Grid view" : "Vista de cuadrícula",
    "Start a conversation" : "Iniciar una conversación",
    "Media" : "Media",
    "Locations" : "Ubicaciones",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Do not disturb" : "No molestar",
    "Away" : "Lejos",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
    "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "Android app" : "Aplicación android",
    "iOS app" : "Aplicación iOS",
    "Rename conversation" : "Renombrar conversación"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
